# Plan — 归档

已完成 / 被替代的 milestone。原文件保留不改写。

| # | 标题 | 完成时间 | 状态 |
|---|---|---|---|
| [M1](M1-scaffold.md) | epsilon provision + FastAPI + systemd | 2026-04-22 | ✅ 完成 |
| [M2](M2-core-flow.md) | 注册 / profile / query / mock 付费曝光 | 2026-04-22 | ✅ 完成 |
| [M3](M3-backup-smoke.md) | OSS 备份 + restore 演练 | 2026-04-22 | ✅ 完成 |
| [M4](M4-sell-first-user.md) | 第一个付费意向用户（原版 "1 对 1 访谈"）| 2026-04-22 | ⚠️ **pivot 替代**：原计划"1 对 1 访谈"→ ADR 2026-04-22-2230 改 "skill 发布 + 视频" → 2026-04-23 drop-exposure 砍付费曝光换虚拟信封商业模式。M4 内容完全被替代，新方向见 O3 / M6 |
